import { DeepPartial } from './utils';
import * as z from 'zod';
export declare const configSchema: z.ZodObject<{
    api: z.ZodObject<{
        baseUrl: z.ZodEffects<z.ZodString, string, string>;
        hubUrl: z.ZodEffects<z.ZodString, string, string>;
        qualityBaseUrl: z.ZodEffects<z.ZodString, string, string>;
        similarityBaseUrl: z.ZodEffects<z.ZodString, string, string>;
        similarityServiceName: z.ZodDefault<z.ZodString>;
        fileUploadUrl: z.ZodEffects<z.ZodString, string, string>;
        sparqlUrl: z.ZodEffects<z.ZodString, string, string>;
        gazetteerBaseUrl: z.ZodEffects<z.ZodString, string, string>;
        corsproxyApiUrl: z.ZodEffects<z.ZodString, string, string>;
    }, "strip", z.ZodTypeAny, {
        baseUrl: string;
        hubUrl: string;
        qualityBaseUrl: string;
        similarityBaseUrl: string;
        similarityServiceName: string;
        fileUploadUrl: string;
        sparqlUrl: string;
        gazetteerBaseUrl: string;
        corsproxyApiUrl: string;
    }, {
        baseUrl: string;
        hubUrl: string;
        qualityBaseUrl: string;
        similarityBaseUrl: string;
        fileUploadUrl: string;
        sparqlUrl: string;
        gazetteerBaseUrl: string;
        corsproxyApiUrl: string;
        similarityServiceName?: string | undefined;
    }>;
    authentication: z.ZodDefault<z.ZodObject<{
        useService: z.ZodDefault<z.ZodBoolean>;
        login: z.ZodDefault<z.ZodObject<{
            useLogin: z.ZodDefault<z.ZodBoolean>;
            loginTitle: z.ZodDefault<z.ZodString>;
            loginURL: z.ZodDefault<z.ZodString>;
            loginRedirectUri: z.ZodDefault<z.ZodString>;
            logoutTitle: z.ZodDefault<z.ZodString>;
            logoutURL: z.ZodDefault<z.ZodString>;
            logoutRedirectUri: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            useLogin: boolean;
            loginTitle: string;
            loginURL: string;
            loginRedirectUri: string;
            logoutTitle: string;
            logoutURL: string;
            logoutRedirectUri: string;
        }, {
            useLogin?: boolean | undefined;
            loginTitle?: string | undefined;
            loginURL?: string | undefined;
            loginRedirectUri?: string | undefined;
            logoutTitle?: string | undefined;
            logoutURL?: string | undefined;
            logoutRedirectUri?: string | undefined;
        }>>;
        keycloak: z.ZodDefault<z.ZodObject<{
            realm: z.ZodDefault<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            clientId: z.ZodDefault<z.ZodString>;
            'ssl-required': z.ZodDefault<z.ZodString>;
            'public-client': z.ZodDefault<z.ZodBoolean>;
            'verify-token-audience': z.ZodDefault<z.ZodBoolean>;
            'use-resource-role-mappings': z.ZodDefault<z.ZodBoolean>;
            'confidential-port': z.ZodDefault<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            realm: string;
            clientId: string;
            'ssl-required': string;
            'public-client': boolean;
            'verify-token-audience': boolean;
            'use-resource-role-mappings': boolean;
            'confidential-port': number;
            url?: string | undefined;
        }, {
            realm?: string | undefined;
            url?: string | undefined;
            clientId?: string | undefined;
            'ssl-required'?: string | undefined;
            'public-client'?: boolean | undefined;
            'verify-token-audience'?: boolean | undefined;
            'use-resource-role-mappings'?: boolean | undefined;
            'confidential-port'?: number | undefined;
        }>>;
        keycloakInit: z.ZodDefault<z.ZodObject<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">>>;
        rtp: z.ZodDefault<z.ZodObject<{
            grand_type: z.ZodDefault<z.ZodString>;
            audience: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            grand_type: string;
            audience: string;
        }, {
            grand_type?: string | undefined;
            audience?: string | undefined;
        }>>;
        authToken: z.ZodDefault<z.ZodString>;
        authMiddleware: z.ZodDefault<z.ZodObject<{
            enable: z.ZodDefault<z.ZodBoolean>;
            baseUrl: z.ZodDefault<z.ZodString>;
            loginRedirectUrl: z.ZodDefault<z.ZodString>;
            logoutRedirectUrl: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            baseUrl: string;
            enable: boolean;
            loginRedirectUrl: string;
            logoutRedirectUrl: string;
        }, {
            baseUrl?: string | undefined;
            enable?: boolean | undefined;
            loginRedirectUrl?: string | undefined;
            logoutRedirectUrl?: string | undefined;
        }>>;
    }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
        useService: z.ZodDefault<z.ZodBoolean>;
        login: z.ZodDefault<z.ZodObject<{
            useLogin: z.ZodDefault<z.ZodBoolean>;
            loginTitle: z.ZodDefault<z.ZodString>;
            loginURL: z.ZodDefault<z.ZodString>;
            loginRedirectUri: z.ZodDefault<z.ZodString>;
            logoutTitle: z.ZodDefault<z.ZodString>;
            logoutURL: z.ZodDefault<z.ZodString>;
            logoutRedirectUri: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            useLogin: boolean;
            loginTitle: string;
            loginURL: string;
            loginRedirectUri: string;
            logoutTitle: string;
            logoutURL: string;
            logoutRedirectUri: string;
        }, {
            useLogin?: boolean | undefined;
            loginTitle?: string | undefined;
            loginURL?: string | undefined;
            loginRedirectUri?: string | undefined;
            logoutTitle?: string | undefined;
            logoutURL?: string | undefined;
            logoutRedirectUri?: string | undefined;
        }>>;
        keycloak: z.ZodDefault<z.ZodObject<{
            realm: z.ZodDefault<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            clientId: z.ZodDefault<z.ZodString>;
            'ssl-required': z.ZodDefault<z.ZodString>;
            'public-client': z.ZodDefault<z.ZodBoolean>;
            'verify-token-audience': z.ZodDefault<z.ZodBoolean>;
            'use-resource-role-mappings': z.ZodDefault<z.ZodBoolean>;
            'confidential-port': z.ZodDefault<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            realm: string;
            clientId: string;
            'ssl-required': string;
            'public-client': boolean;
            'verify-token-audience': boolean;
            'use-resource-role-mappings': boolean;
            'confidential-port': number;
            url?: string | undefined;
        }, {
            realm?: string | undefined;
            url?: string | undefined;
            clientId?: string | undefined;
            'ssl-required'?: string | undefined;
            'public-client'?: boolean | undefined;
            'verify-token-audience'?: boolean | undefined;
            'use-resource-role-mappings'?: boolean | undefined;
            'confidential-port'?: number | undefined;
        }>>;
        keycloakInit: z.ZodDefault<z.ZodObject<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">>>;
        rtp: z.ZodDefault<z.ZodObject<{
            grand_type: z.ZodDefault<z.ZodString>;
            audience: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            grand_type: string;
            audience: string;
        }, {
            grand_type?: string | undefined;
            audience?: string | undefined;
        }>>;
        authToken: z.ZodDefault<z.ZodString>;
        authMiddleware: z.ZodDefault<z.ZodObject<{
            enable: z.ZodDefault<z.ZodBoolean>;
            baseUrl: z.ZodDefault<z.ZodString>;
            loginRedirectUrl: z.ZodDefault<z.ZodString>;
            logoutRedirectUrl: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            baseUrl: string;
            enable: boolean;
            loginRedirectUrl: string;
            logoutRedirectUrl: string;
        }, {
            baseUrl?: string | undefined;
            enable?: boolean | undefined;
            loginRedirectUrl?: string | undefined;
            logoutRedirectUrl?: string | undefined;
        }>>;
    }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
        useService: z.ZodDefault<z.ZodBoolean>;
        login: z.ZodDefault<z.ZodObject<{
            useLogin: z.ZodDefault<z.ZodBoolean>;
            loginTitle: z.ZodDefault<z.ZodString>;
            loginURL: z.ZodDefault<z.ZodString>;
            loginRedirectUri: z.ZodDefault<z.ZodString>;
            logoutTitle: z.ZodDefault<z.ZodString>;
            logoutURL: z.ZodDefault<z.ZodString>;
            logoutRedirectUri: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            useLogin: boolean;
            loginTitle: string;
            loginURL: string;
            loginRedirectUri: string;
            logoutTitle: string;
            logoutURL: string;
            logoutRedirectUri: string;
        }, {
            useLogin?: boolean | undefined;
            loginTitle?: string | undefined;
            loginURL?: string | undefined;
            loginRedirectUri?: string | undefined;
            logoutTitle?: string | undefined;
            logoutURL?: string | undefined;
            logoutRedirectUri?: string | undefined;
        }>>;
        keycloak: z.ZodDefault<z.ZodObject<{
            realm: z.ZodDefault<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            clientId: z.ZodDefault<z.ZodString>;
            'ssl-required': z.ZodDefault<z.ZodString>;
            'public-client': z.ZodDefault<z.ZodBoolean>;
            'verify-token-audience': z.ZodDefault<z.ZodBoolean>;
            'use-resource-role-mappings': z.ZodDefault<z.ZodBoolean>;
            'confidential-port': z.ZodDefault<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            realm: string;
            clientId: string;
            'ssl-required': string;
            'public-client': boolean;
            'verify-token-audience': boolean;
            'use-resource-role-mappings': boolean;
            'confidential-port': number;
            url?: string | undefined;
        }, {
            realm?: string | undefined;
            url?: string | undefined;
            clientId?: string | undefined;
            'ssl-required'?: string | undefined;
            'public-client'?: boolean | undefined;
            'verify-token-audience'?: boolean | undefined;
            'use-resource-role-mappings'?: boolean | undefined;
            'confidential-port'?: number | undefined;
        }>>;
        keycloakInit: z.ZodDefault<z.ZodObject<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">>>;
        rtp: z.ZodDefault<z.ZodObject<{
            grand_type: z.ZodDefault<z.ZodString>;
            audience: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            grand_type: string;
            audience: string;
        }, {
            grand_type?: string | undefined;
            audience?: string | undefined;
        }>>;
        authToken: z.ZodDefault<z.ZodString>;
        authMiddleware: z.ZodDefault<z.ZodObject<{
            enable: z.ZodDefault<z.ZodBoolean>;
            baseUrl: z.ZodDefault<z.ZodString>;
            loginRedirectUrl: z.ZodDefault<z.ZodString>;
            logoutRedirectUrl: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            baseUrl: string;
            enable: boolean;
            loginRedirectUrl: string;
            logoutRedirectUrl: string;
        }, {
            baseUrl?: string | undefined;
            enable?: boolean | undefined;
            loginRedirectUrl?: string | undefined;
            logoutRedirectUrl?: string | undefined;
        }>>;
    }, z.ZodTypeAny, "passthrough">>>;
    /**
     * Routing options (optional).
     */
    routing: z.ZodDefault<z.ZodObject<{
        routerOptions: z.ZodDefault<z.ZodObject<{
            base: z.ZodDefault<z.ZodString>;
            mode: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            base: string;
            mode: string;
        }, {
            base?: string | undefined;
            mode?: string | undefined;
        }>>;
        navigation: z.ZodDefault<z.ZodObject<{
            showSparql: z.ZodDefault<z.ZodBoolean>;
        }, "strip", z.ZodTypeAny, {
            showSparql: boolean;
        }, {
            showSparql?: boolean | undefined;
        }>>;
        pagination: z.ZodDefault<z.ZodObject<{
            usePagination: z.ZodDefault<z.ZodBoolean>;
            usePaginationArrows: z.ZodDefault<z.ZodBoolean>;
            useItemsPerPage: z.ZodDefault<z.ZodBoolean>;
            defaultItemsPerPage: z.ZodDefault<z.ZodNumber>;
            defaultItemsPerPageOptions: z.ZodDefault<z.ZodArray<z.ZodNumber, "many">>;
        }, "strip", z.ZodTypeAny, {
            usePagination: boolean;
            usePaginationArrows: boolean;
            useItemsPerPage: boolean;
            defaultItemsPerPage: number;
            defaultItemsPerPageOptions: number[];
        }, {
            usePagination?: boolean | undefined;
            usePaginationArrows?: boolean | undefined;
            useItemsPerPage?: boolean | undefined;
            defaultItemsPerPage?: number | undefined;
            defaultItemsPerPageOptions?: number[] | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        routerOptions: {
            base: string;
            mode: string;
        };
        navigation: {
            showSparql: boolean;
        };
        pagination: {
            usePagination: boolean;
            usePaginationArrows: boolean;
            useItemsPerPage: boolean;
            defaultItemsPerPage: number;
            defaultItemsPerPageOptions: number[];
        };
    }, {
        routerOptions?: {
            base?: string | undefined;
            mode?: string | undefined;
        } | undefined;
        navigation?: {
            showSparql?: boolean | undefined;
        } | undefined;
        pagination?: {
            usePagination?: boolean | undefined;
            usePaginationArrows?: boolean | undefined;
            useItemsPerPage?: boolean | undefined;
            defaultItemsPerPage?: number | undefined;
            defaultItemsPerPageOptions?: number[] | undefined;
        } | undefined;
    }>>;
    /**
     * Metadata options (optional).
     */
    metadata: z.ZodDefault<z.ZodObject<{
        title: z.ZodDefault<z.ZodString>;
        description: z.ZodDefault<z.ZodString>;
        keywords: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        title: string;
        description: string;
        keywords: string;
    }, {
        title?: string | undefined;
        description?: string | undefined;
        keywords?: string | undefined;
    }>>;
    /**
     * Content options (optional).
     */
    content: z.ZodDefault<z.ZodObject<{
        datasets: z.ZodDefault<z.ZodObject<{
            useSort: z.ZodDefault<z.ZodBoolean>;
            useFeed: z.ZodDefault<z.ZodBoolean>;
            useCatalogs: z.ZodDefault<z.ZodBoolean>;
            followKeywordLinks: z.ZodDefault<z.ZodString>;
            maxKeywordLength: z.ZodDefault<z.ZodNumber>;
            facets: z.ZodDefault<z.ZodObject<{
                useDatasetFacets: z.ZodDefault<z.ZodBoolean>;
                useDatasetFacetsMap: z.ZodDefault<z.ZodBoolean>;
                showClearButton: z.ZodDefault<z.ZodBoolean>;
                showFacetsTitle: z.ZodDefault<z.ZodBoolean>;
                cutoff: z.ZodDefault<z.ZodNumber>;
                MIN_FACET_LIMIT: z.ZodDefault<z.ZodNumber>;
                MAX_FACET_LIMIT: z.ZodDefault<z.ZodNumber>;
                FACET_OPERATORS: z.ZodDefault<z.ZodObject<{
                    or: z.ZodDefault<z.ZodString>;
                    and: z.ZodDefault<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    or: string;
                    and: string;
                }, {
                    or?: string | undefined;
                    and?: string | undefined;
                }>>;
                FACET_GROUP_OPERATORS: z.ZodDefault<z.ZodObject<{
                    or: z.ZodDefault<z.ZodString>;
                    and: z.ZodDefault<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    or: string;
                    and: string;
                }, {
                    or?: string | undefined;
                    and?: string | undefined;
                }>>;
                defaultFacetOrder: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
                scoringFacets: z.ZodDefault<z.ZodObject<{
                    useScoringFacets: z.ZodDefault<z.ZodBoolean>;
                    defaultScoringFacets: z.ZodDefault<z.ZodRecord<z.ZodString, z.ZodObject<{
                        id: z.ZodString;
                        title: z.ZodString;
                        count: z.ZodNumber;
                        minScoring: z.ZodNumber;
                        maxScoring: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }>>>;
                }, "strip", z.ZodTypeAny, {
                    useScoringFacets: boolean;
                    defaultScoringFacets: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }>;
                }, {
                    useScoringFacets?: boolean | undefined;
                    defaultScoringFacets?: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }> | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                useDatasetFacets: boolean;
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                scoringFacets: {
                    useScoringFacets: boolean;
                    defaultScoringFacets: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }>;
                };
            }, {
                useDatasetFacets?: boolean | undefined;
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                scoringFacets?: {
                    useScoringFacets?: boolean | undefined;
                    defaultScoringFacets?: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }> | undefined;
                } | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            useSort: boolean;
            useFeed: boolean;
            useCatalogs: boolean;
            followKeywordLinks: string;
            maxKeywordLength: number;
            facets: {
                useDatasetFacets: boolean;
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                scoringFacets: {
                    useScoringFacets: boolean;
                    defaultScoringFacets: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }>;
                };
            };
        }, {
            useSort?: boolean | undefined;
            useFeed?: boolean | undefined;
            useCatalogs?: boolean | undefined;
            followKeywordLinks?: string | undefined;
            maxKeywordLength?: number | undefined;
            facets?: {
                useDatasetFacets?: boolean | undefined;
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                scoringFacets?: {
                    useScoringFacets?: boolean | undefined;
                    defaultScoringFacets?: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }> | undefined;
                } | undefined;
            } | undefined;
        }>>;
        catalogs: z.ZodDefault<z.ZodObject<{
            useSort: z.ZodDefault<z.ZodBoolean>;
            useCatalogCountries: z.ZodDefault<z.ZodBoolean>;
            defaultCatalogImagePath: z.ZodDefault<z.ZodString>;
            defaultCatalogCountryID: z.ZodDefault<z.ZodString>;
            defaultCatalogID: z.ZodDefault<z.ZodString>;
            facets: z.ZodDefault<z.ZodObject<{
                useCatalogFacets: z.ZodDefault<z.ZodBoolean>;
                showClearButton: z.ZodDefault<z.ZodBoolean>;
                showFacetsTitle: z.ZodDefault<z.ZodBoolean>;
                cutoff: z.ZodDefault<z.ZodNumber>;
                MIN_FACET_LIMIT: z.ZodDefault<z.ZodNumber>;
                MAX_FACET_LIMIT: z.ZodDefault<z.ZodNumber>;
                FACET_OPERATORS: z.ZodDefault<z.ZodObject<{
                    or: z.ZodDefault<z.ZodString>;
                    and: z.ZodDefault<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    or: string;
                    and: string;
                }, {
                    or?: string | undefined;
                    and?: string | undefined;
                }>>;
                FACET_GROUP_OPERATORS: z.ZodDefault<z.ZodObject<{
                    or: z.ZodDefault<z.ZodString>;
                    and: z.ZodDefault<z.ZodString>;
                }, "strip", z.ZodTypeAny, {
                    or: string;
                    and: string;
                }, {
                    or?: string | undefined;
                    and?: string | undefined;
                }>>;
                defaultFacetOrder: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
                useDatasetFacetsMap: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                useCatalogFacets: boolean;
            }, {
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                useCatalogFacets?: boolean | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            useSort: boolean;
            facets: {
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                useCatalogFacets: boolean;
            };
            useCatalogCountries: boolean;
            defaultCatalogImagePath: string;
            defaultCatalogCountryID: string;
            defaultCatalogID: string;
        }, {
            useSort?: boolean | undefined;
            facets?: {
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                useCatalogFacets?: boolean | undefined;
            } | undefined;
            useCatalogCountries?: boolean | undefined;
            defaultCatalogImagePath?: string | undefined;
            defaultCatalogCountryID?: string | undefined;
            defaultCatalogID?: string | undefined;
        }>>;
        datasetDetails: z.ZodDefault<z.ZodObject<{
            properties: z.ZodDefault<z.ZodString>;
            embed: z.ZodDefault<z.ZodObject<{
                enable: z.ZodDefault<z.ZodBoolean>;
                defaultWidth: z.ZodDefault<z.ZodNumber>;
                defaultHeight: z.ZodDefault<z.ZodNumber>;
                minRange: z.ZodDefault<z.ZodNumber>;
                maxRange: z.ZodDefault<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                enable: boolean;
                defaultWidth: number;
                defaultHeight: number;
                minRange: number;
                maxRange: number;
            }, {
                enable?: boolean | undefined;
                defaultWidth?: number | undefined;
                defaultHeight?: number | undefined;
                minRange?: number | undefined;
                maxRange?: number | undefined;
            }>>;
            header: z.ZodDefault<z.ZodObject<{
                navigation: z.ZodDefault<z.ZodString>;
                hidePublisher: z.ZodDefault<z.ZodBoolean>;
                hideDate: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                navigation: string;
                hidePublisher: boolean;
                hideDate: boolean;
            }, {
                navigation?: string | undefined;
                hidePublisher?: boolean | undefined;
                hideDate?: boolean | undefined;
            }>>;
            keywords: z.ZodDefault<z.ZodObject<{
                showTitle: z.ZodDefault<z.ZodBoolean>;
                isVisible: z.ZodDefault<z.ZodBoolean>;
                collapsed: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                showTitle: boolean;
                isVisible: boolean;
                collapsed: boolean;
            }, {
                showTitle?: boolean | undefined;
                isVisible?: boolean | undefined;
                collapsed?: boolean | undefined;
            }>>;
            description: z.ZodDefault<z.ZodObject<{
                enableMarkdownInterpretation: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                enableMarkdownInterpretation: boolean;
            }, {
                enableMarkdownInterpretation?: boolean | undefined;
            }>>;
            distributions: z.ZodDefault<z.ZodObject<{
                displayAll: z.ZodDefault<z.ZodBoolean>;
                displayCount: z.ZodDefault<z.ZodNumber>;
                incrementSteps: z.ZodDefault<z.ZodArray<z.ZodNumber, "many">>;
                descriptionMaxLines: z.ZodDefault<z.ZodNumber>;
                descriptionMaxChars: z.ZodDefault<z.ZodNumber>;
                showValidationButton: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
                showValidationButton: boolean;
            }, {
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
                showValidationButton?: boolean | undefined;
            }>>;
            downloadAs: z.ZodDefault<z.ZodObject<{
                enable: z.ZodDefault<z.ZodBoolean>;
                proxyUrl: z.ZodDefault<z.ZodString>;
                url: z.ZodDefault<z.ZodString>;
                conversionFormats: z.ZodDefault<z.ZodArray<z.ZodObject<{
                    sourceFileFormat: z.ZodString;
                    targetFileFormat: z.ZodArray<z.ZodString, "many">;
                }, "strip", z.ZodTypeAny, {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }, {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }>, "many">>;
            }, "strip", z.ZodTypeAny, {
                url: string;
                enable: boolean;
                proxyUrl: string;
                conversionFormats: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[];
            }, {
                url?: string | undefined;
                enable?: boolean | undefined;
                proxyUrl?: string | undefined;
                conversionFormats?: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[] | undefined;
            }>>;
            similarDatasets: z.ZodDefault<z.ZodObject<{
                useSimilarDatasets: z.ZodDefault<z.ZodBoolean>;
                breakpoints: z.ZodDefault<z.ZodObject<{
                    verySimilar: z.ZodDefault<z.ZodEffects<z.ZodObject<{
                        start: z.ZodNumber;
                        end: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        start: number;
                        end: number;
                    }, {
                        start: number;
                        end: number;
                    }>, {
                        start: number;
                        end: number;
                    }, {
                        start: number;
                        end: number;
                    }>>;
                    similar: z.ZodDefault<z.ZodEffects<z.ZodObject<{
                        start: z.ZodNumber;
                        end: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        start: number;
                        end: number;
                    }, {
                        start: number;
                        end: number;
                    }>, {
                        start: number;
                        end: number;
                    }, {
                        start: number;
                        end: number;
                    }>>;
                    lessSimilar: z.ZodDefault<z.ZodEffects<z.ZodObject<{
                        start: z.ZodNumber;
                        end: z.ZodNumber;
                    }, "strip", z.ZodTypeAny, {
                        start: number;
                        end: number;
                    }, {
                        start: number;
                        end: number;
                    }>, {
                        start: number;
                        end: number;
                    }, {
                        start: number;
                        end: number;
                    }>>;
                }, "strip", z.ZodTypeAny, {
                    verySimilar: {
                        start: number;
                        end: number;
                    };
                    similar: {
                        start: number;
                        end: number;
                    };
                    lessSimilar: {
                        start: number;
                        end: number;
                    };
                }, {
                    verySimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    similar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    lessSimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                useSimilarDatasets: boolean;
                breakpoints: {
                    verySimilar: {
                        start: number;
                        end: number;
                    };
                    similar: {
                        start: number;
                        end: number;
                    };
                    lessSimilar: {
                        start: number;
                        end: number;
                    };
                };
            }, {
                useSimilarDatasets?: boolean | undefined;
                breakpoints?: {
                    verySimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    similar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    lessSimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                } | undefined;
            }>>;
            pages: z.ZodDefault<z.ZodObject<{
                isVisible: z.ZodDefault<z.ZodBoolean>;
                displayAll: z.ZodDefault<z.ZodBoolean>;
                displayCount: z.ZodDefault<z.ZodNumber>;
                incrementSteps: z.ZodDefault<z.ZodArray<z.ZodNumber, "many">>;
                descriptionMaxLines: z.ZodDefault<z.ZodNumber>;
                descriptionMaxChars: z.ZodDefault<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            }, {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            }>>;
            visualisations: z.ZodDefault<z.ZodObject<{
                isVisible: z.ZodDefault<z.ZodBoolean>;
                displayAll: z.ZodDefault<z.ZodBoolean>;
                displayCount: z.ZodDefault<z.ZodNumber>;
                incrementSteps: z.ZodDefault<z.ZodArray<z.ZodNumber, "many">>;
                descriptionMaxLines: z.ZodDefault<z.ZodNumber>;
                descriptionMaxChars: z.ZodDefault<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            }, {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            }>>;
            dataServices: z.ZodDefault<z.ZodObject<{
                isVisible: z.ZodDefault<z.ZodBoolean>;
                displayAll: z.ZodDefault<z.ZodBoolean>;
                displayCount: z.ZodDefault<z.ZodNumber>;
                incrementSteps: z.ZodDefault<z.ZodArray<z.ZodNumber, "many">>;
                descriptionMaxLines: z.ZodDefault<z.ZodNumber>;
                descriptionMaxChars: z.ZodDefault<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            }, {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            }>>;
            isUsedBy: z.ZodDefault<z.ZodObject<{
                isVisible: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                isVisible: boolean;
            }, {
                isVisible?: boolean | undefined;
            }>>;
            relatedResources: z.ZodDefault<z.ZodObject<{
                isVisible: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                isVisible: boolean;
            }, {
                isVisible?: boolean | undefined;
            }>>;
            bulkDownload: z.ZodDefault<z.ZodObject<{
                buttonPosition: z.ZodDefault<z.ZodString>;
                MAX_FILE_TITLE_LENGTH: z.ZodDefault<z.ZodNumber>;
                MAX_REQUESTS_COUNT: z.ZodDefault<z.ZodNumber>;
                INTERVAL_MS: z.ZodDefault<z.ZodNumber>;
                TIMEOUT_MS: z.ZodDefault<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                buttonPosition: string;
                MAX_FILE_TITLE_LENGTH: number;
                MAX_REQUESTS_COUNT: number;
                INTERVAL_MS: number;
                TIMEOUT_MS: number;
            }, {
                buttonPosition?: string | undefined;
                MAX_FILE_TITLE_LENGTH?: number | undefined;
                MAX_REQUESTS_COUNT?: number | undefined;
                INTERVAL_MS?: number | undefined;
                TIMEOUT_MS?: number | undefined;
            }>>;
            quality: z.ZodDefault<z.ZodObject<{
                displayAll: z.ZodDefault<z.ZodBoolean>;
                numberOfDisplayedQualityDistributions: z.ZodDefault<z.ZodNumber>;
                csvLinter: z.ZodDefault<z.ZodObject<{
                    enable: z.ZodDefault<z.ZodBoolean>;
                    displayAll: z.ZodDefault<z.ZodBoolean>;
                    numberOfDisplayedValidationResults: z.ZodDefault<z.ZodNumber>;
                }, "strip", z.ZodTypeAny, {
                    enable: boolean;
                    displayAll: boolean;
                    numberOfDisplayedValidationResults: number;
                }, {
                    enable?: boolean | undefined;
                    displayAll?: boolean | undefined;
                    numberOfDisplayedValidationResults?: number | undefined;
                }>>;
            }, "strip", z.ZodTypeAny, {
                displayAll: boolean;
                numberOfDisplayedQualityDistributions: number;
                csvLinter: {
                    enable: boolean;
                    displayAll: boolean;
                    numberOfDisplayedValidationResults: number;
                };
            }, {
                displayAll?: boolean | undefined;
                numberOfDisplayedQualityDistributions?: number | undefined;
                csvLinter?: {
                    enable?: boolean | undefined;
                    displayAll?: boolean | undefined;
                    numberOfDisplayedValidationResults?: number | undefined;
                } | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            embed: {
                enable: boolean;
                defaultWidth: number;
                defaultHeight: number;
                minRange: number;
                maxRange: number;
            };
            header: {
                navigation: string;
                hidePublisher: boolean;
                hideDate: boolean;
            };
            description: {
                enableMarkdownInterpretation: boolean;
            };
            keywords: {
                showTitle: boolean;
                isVisible: boolean;
                collapsed: boolean;
            };
            dataServices: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            properties: string;
            distributions: {
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
                showValidationButton: boolean;
            };
            downloadAs: {
                url: string;
                enable: boolean;
                proxyUrl: string;
                conversionFormats: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[];
            };
            similarDatasets: {
                useSimilarDatasets: boolean;
                breakpoints: {
                    verySimilar: {
                        start: number;
                        end: number;
                    };
                    similar: {
                        start: number;
                        end: number;
                    };
                    lessSimilar: {
                        start: number;
                        end: number;
                    };
                };
            };
            pages: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            visualisations: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            isUsedBy: {
                isVisible: boolean;
            };
            relatedResources: {
                isVisible: boolean;
            };
            bulkDownload: {
                buttonPosition: string;
                MAX_FILE_TITLE_LENGTH: number;
                MAX_REQUESTS_COUNT: number;
                INTERVAL_MS: number;
                TIMEOUT_MS: number;
            };
            quality: {
                displayAll: boolean;
                numberOfDisplayedQualityDistributions: number;
                csvLinter: {
                    enable: boolean;
                    displayAll: boolean;
                    numberOfDisplayedValidationResults: number;
                };
            };
        }, {
            embed?: {
                enable?: boolean | undefined;
                defaultWidth?: number | undefined;
                defaultHeight?: number | undefined;
                minRange?: number | undefined;
                maxRange?: number | undefined;
            } | undefined;
            header?: {
                navigation?: string | undefined;
                hidePublisher?: boolean | undefined;
                hideDate?: boolean | undefined;
            } | undefined;
            description?: {
                enableMarkdownInterpretation?: boolean | undefined;
            } | undefined;
            keywords?: {
                showTitle?: boolean | undefined;
                isVisible?: boolean | undefined;
                collapsed?: boolean | undefined;
            } | undefined;
            dataServices?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            properties?: string | undefined;
            distributions?: {
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
                showValidationButton?: boolean | undefined;
            } | undefined;
            downloadAs?: {
                url?: string | undefined;
                enable?: boolean | undefined;
                proxyUrl?: string | undefined;
                conversionFormats?: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[] | undefined;
            } | undefined;
            similarDatasets?: {
                useSimilarDatasets?: boolean | undefined;
                breakpoints?: {
                    verySimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    similar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    lessSimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                } | undefined;
            } | undefined;
            pages?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            visualisations?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            isUsedBy?: {
                isVisible?: boolean | undefined;
            } | undefined;
            relatedResources?: {
                isVisible?: boolean | undefined;
            } | undefined;
            bulkDownload?: {
                buttonPosition?: string | undefined;
                MAX_FILE_TITLE_LENGTH?: number | undefined;
                MAX_REQUESTS_COUNT?: number | undefined;
                INTERVAL_MS?: number | undefined;
                TIMEOUT_MS?: number | undefined;
            } | undefined;
            quality?: {
                displayAll?: boolean | undefined;
                numberOfDisplayedQualityDistributions?: number | undefined;
                csvLinter?: {
                    enable?: boolean | undefined;
                    displayAll?: boolean | undefined;
                    numberOfDisplayedValidationResults?: number | undefined;
                } | undefined;
            } | undefined;
        }>>;
        maps: z.ZodDefault<z.ZodObject<{
            mapVisible: z.ZodDefault<z.ZodBoolean>;
            useAnimation: z.ZodDefault<z.ZodBoolean>;
            location: z.ZodDefault<z.ZodTuple<[z.ZodArray<z.ZodNumber, "many">, z.ZodNumber], null>>;
            spatialType: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"Point">, z.ZodLiteral<"Polygon">]>>;
            height: z.ZodDefault<z.ZodString>;
            width: z.ZodDefault<z.ZodString>;
            mapContainerId: z.ZodDefault<z.ZodString>;
            urlTemplate: z.ZodDefault<z.ZodString>;
            geoBoundsId: z.ZodDefault<z.ZodString>;
            sender: z.ZodDefault<z.ZodObject<{
                startBounds: z.ZodDefault<z.ZodTuple<[z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>], null>>;
                height: z.ZodDefault<z.ZodString>;
                width: z.ZodDefault<z.ZodString>;
                mapContainerId: z.ZodDefault<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
            }, {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
            }>>;
            receiver: z.ZodDefault<z.ZodObject<{
                startBounds: z.ZodDefault<z.ZodTuple<[z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>, z.ZodTuple<[z.ZodNumber, z.ZodNumber], null>], null>>;
                height: z.ZodDefault<z.ZodString>;
                width: z.ZodDefault<z.ZodString>;
                mapContainerId: z.ZodDefault<z.ZodString>;
                attributionPosition: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"topleft">, z.ZodLiteral<"topright">, z.ZodLiteral<"bottomleft">, z.ZodLiteral<"bottomright">]>>;
            }, "strip", z.ZodTypeAny, {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
                attributionPosition: "topleft" | "topright" | "bottomleft" | "bottomright";
            }, {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
                attributionPosition?: "topleft" | "topright" | "bottomleft" | "bottomright" | undefined;
            }>>;
            options: z.ZodDefault<z.ZodObject<{
                id: z.ZodDefault<z.ZodString>;
                accessToken: z.ZodDefault<z.ZodString>;
                attribution: z.ZodDefault<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                id: string;
                accessToken: string;
                attribution: string;
            }, {
                id?: string | undefined;
                accessToken?: string | undefined;
                attribution?: string | undefined;
            }>>;
            mapStyle: z.ZodDefault<z.ZodObject<{
                color: z.ZodDefault<z.ZodString>;
                fillColor: z.ZodDefault<z.ZodString>;
                fillOpacity: z.ZodDefault<z.ZodNumber>;
                weight: z.ZodDefault<z.ZodNumber>;
                radius: z.ZodDefault<z.ZodNumber>;
            }, "strip", z.ZodTypeAny, {
                color: string;
                fillColor: string;
                fillOpacity: number;
                weight: number;
                radius: number;
            }, {
                color?: string | undefined;
                fillColor?: string | undefined;
                fillOpacity?: number | undefined;
                weight?: number | undefined;
                radius?: number | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            options: {
                id: string;
                accessToken: string;
                attribution: string;
            };
            mapVisible: boolean;
            useAnimation: boolean;
            location: [number[], number];
            spatialType: "Point" | "Polygon";
            height: string;
            width: string;
            mapContainerId: string;
            urlTemplate: string;
            geoBoundsId: string;
            sender: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
            };
            receiver: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
                attributionPosition: "topleft" | "topright" | "bottomleft" | "bottomright";
            };
            mapStyle: {
                color: string;
                fillColor: string;
                fillOpacity: number;
                weight: number;
                radius: number;
            };
        }, {
            options?: {
                id?: string | undefined;
                accessToken?: string | undefined;
                attribution?: string | undefined;
            } | undefined;
            mapVisible?: boolean | undefined;
            useAnimation?: boolean | undefined;
            location?: [number[], number] | undefined;
            spatialType?: "Point" | "Polygon" | undefined;
            height?: string | undefined;
            width?: string | undefined;
            mapContainerId?: string | undefined;
            urlTemplate?: string | undefined;
            geoBoundsId?: string | undefined;
            sender?: {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
            } | undefined;
            receiver?: {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
                attributionPosition?: "topleft" | "topright" | "bottomleft" | "bottomright" | undefined;
            } | undefined;
            mapStyle?: {
                color?: string | undefined;
                fillColor?: string | undefined;
                fillOpacity?: number | undefined;
                weight?: number | undefined;
                radius?: number | undefined;
            } | undefined;
        }>>;
        dataProviderInterface: z.ZodDefault<z.ZodObject<{
            uploadFileTypes: z.ZodDefault<z.ZodArray<z.ZodString, "many">>;
            useService: z.ZodDefault<z.ZodBoolean>;
            enableFileUploadReplace: z.ZodDefault<z.ZodBoolean>;
            basePath: z.ZodDefault<z.ZodString>;
            specification: z.ZodDefault<z.ZodUnion<[z.ZodLiteral<"dcatap">, z.ZodLiteral<"dcatapde">]>>;
            annifIntegration: z.ZodDefault<z.ZodBoolean>;
            annifLinkTheme: z.ZodDefault<z.ZodString>;
            annifLinkSubject: z.ZodDefault<z.ZodString>;
            buttons: z.ZodDefault<z.ZodObject<{
                Dataset: z.ZodDefault<z.ZodBoolean>;
                Catalogue: z.ZodDefault<z.ZodBoolean>;
            }, "strip", z.ZodTypeAny, {
                Dataset: boolean;
                Catalogue: boolean;
            }, {
                Dataset?: boolean | undefined;
                Catalogue?: boolean | undefined;
            }>>;
            doiRegistrationService: z.ZodDefault<z.ZodObject<{
                persistentIdentifierType: z.ZodDefault<z.ZodString>;
            }, "strip", z.ZodTypeAny, {
                persistentIdentifierType: string;
            }, {
                persistentIdentifierType?: string | undefined;
            }>>;
        }, "strip", z.ZodTypeAny, {
            useService: boolean;
            uploadFileTypes: string[];
            enableFileUploadReplace: boolean;
            basePath: string;
            specification: "dcatap" | "dcatapde";
            annifIntegration: boolean;
            annifLinkTheme: string;
            annifLinkSubject: string;
            buttons: {
                Dataset: boolean;
                Catalogue: boolean;
            };
            doiRegistrationService: {
                persistentIdentifierType: string;
            };
        }, {
            useService?: boolean | undefined;
            uploadFileTypes?: string[] | undefined;
            enableFileUploadReplace?: boolean | undefined;
            basePath?: string | undefined;
            specification?: "dcatap" | "dcatapde" | undefined;
            annifIntegration?: boolean | undefined;
            annifLinkTheme?: string | undefined;
            annifLinkSubject?: string | undefined;
            buttons?: {
                Dataset?: boolean | undefined;
                Catalogue?: boolean | undefined;
            } | undefined;
            doiRegistrationService?: {
                persistentIdentifierType?: string | undefined;
            } | undefined;
        }>>;
    }, "strip", z.ZodTypeAny, {
        datasetDetails: {
            embed: {
                enable: boolean;
                defaultWidth: number;
                defaultHeight: number;
                minRange: number;
                maxRange: number;
            };
            header: {
                navigation: string;
                hidePublisher: boolean;
                hideDate: boolean;
            };
            description: {
                enableMarkdownInterpretation: boolean;
            };
            keywords: {
                showTitle: boolean;
                isVisible: boolean;
                collapsed: boolean;
            };
            dataServices: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            properties: string;
            distributions: {
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
                showValidationButton: boolean;
            };
            downloadAs: {
                url: string;
                enable: boolean;
                proxyUrl: string;
                conversionFormats: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[];
            };
            similarDatasets: {
                useSimilarDatasets: boolean;
                breakpoints: {
                    verySimilar: {
                        start: number;
                        end: number;
                    };
                    similar: {
                        start: number;
                        end: number;
                    };
                    lessSimilar: {
                        start: number;
                        end: number;
                    };
                };
            };
            pages: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            visualisations: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            isUsedBy: {
                isVisible: boolean;
            };
            relatedResources: {
                isVisible: boolean;
            };
            bulkDownload: {
                buttonPosition: string;
                MAX_FILE_TITLE_LENGTH: number;
                MAX_REQUESTS_COUNT: number;
                INTERVAL_MS: number;
                TIMEOUT_MS: number;
            };
            quality: {
                displayAll: boolean;
                numberOfDisplayedQualityDistributions: number;
                csvLinter: {
                    enable: boolean;
                    displayAll: boolean;
                    numberOfDisplayedValidationResults: number;
                };
            };
        };
        datasets: {
            useSort: boolean;
            useFeed: boolean;
            useCatalogs: boolean;
            followKeywordLinks: string;
            maxKeywordLength: number;
            facets: {
                useDatasetFacets: boolean;
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                scoringFacets: {
                    useScoringFacets: boolean;
                    defaultScoringFacets: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }>;
                };
            };
        };
        catalogs: {
            useSort: boolean;
            facets: {
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                useCatalogFacets: boolean;
            };
            useCatalogCountries: boolean;
            defaultCatalogImagePath: string;
            defaultCatalogCountryID: string;
            defaultCatalogID: string;
        };
        maps: {
            options: {
                id: string;
                accessToken: string;
                attribution: string;
            };
            mapVisible: boolean;
            useAnimation: boolean;
            location: [number[], number];
            spatialType: "Point" | "Polygon";
            height: string;
            width: string;
            mapContainerId: string;
            urlTemplate: string;
            geoBoundsId: string;
            sender: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
            };
            receiver: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
                attributionPosition: "topleft" | "topright" | "bottomleft" | "bottomright";
            };
            mapStyle: {
                color: string;
                fillColor: string;
                fillOpacity: number;
                weight: number;
                radius: number;
            };
        };
        dataProviderInterface: {
            useService: boolean;
            uploadFileTypes: string[];
            enableFileUploadReplace: boolean;
            basePath: string;
            specification: "dcatap" | "dcatapde";
            annifIntegration: boolean;
            annifLinkTheme: string;
            annifLinkSubject: string;
            buttons: {
                Dataset: boolean;
                Catalogue: boolean;
            };
            doiRegistrationService: {
                persistentIdentifierType: string;
            };
        };
    }, {
        datasetDetails?: {
            embed?: {
                enable?: boolean | undefined;
                defaultWidth?: number | undefined;
                defaultHeight?: number | undefined;
                minRange?: number | undefined;
                maxRange?: number | undefined;
            } | undefined;
            header?: {
                navigation?: string | undefined;
                hidePublisher?: boolean | undefined;
                hideDate?: boolean | undefined;
            } | undefined;
            description?: {
                enableMarkdownInterpretation?: boolean | undefined;
            } | undefined;
            keywords?: {
                showTitle?: boolean | undefined;
                isVisible?: boolean | undefined;
                collapsed?: boolean | undefined;
            } | undefined;
            dataServices?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            properties?: string | undefined;
            distributions?: {
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
                showValidationButton?: boolean | undefined;
            } | undefined;
            downloadAs?: {
                url?: string | undefined;
                enable?: boolean | undefined;
                proxyUrl?: string | undefined;
                conversionFormats?: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[] | undefined;
            } | undefined;
            similarDatasets?: {
                useSimilarDatasets?: boolean | undefined;
                breakpoints?: {
                    verySimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    similar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    lessSimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                } | undefined;
            } | undefined;
            pages?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            visualisations?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            isUsedBy?: {
                isVisible?: boolean | undefined;
            } | undefined;
            relatedResources?: {
                isVisible?: boolean | undefined;
            } | undefined;
            bulkDownload?: {
                buttonPosition?: string | undefined;
                MAX_FILE_TITLE_LENGTH?: number | undefined;
                MAX_REQUESTS_COUNT?: number | undefined;
                INTERVAL_MS?: number | undefined;
                TIMEOUT_MS?: number | undefined;
            } | undefined;
            quality?: {
                displayAll?: boolean | undefined;
                numberOfDisplayedQualityDistributions?: number | undefined;
                csvLinter?: {
                    enable?: boolean | undefined;
                    displayAll?: boolean | undefined;
                    numberOfDisplayedValidationResults?: number | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        datasets?: {
            useSort?: boolean | undefined;
            useFeed?: boolean | undefined;
            useCatalogs?: boolean | undefined;
            followKeywordLinks?: string | undefined;
            maxKeywordLength?: number | undefined;
            facets?: {
                useDatasetFacets?: boolean | undefined;
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                scoringFacets?: {
                    useScoringFacets?: boolean | undefined;
                    defaultScoringFacets?: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }> | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        catalogs?: {
            useSort?: boolean | undefined;
            facets?: {
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                useCatalogFacets?: boolean | undefined;
            } | undefined;
            useCatalogCountries?: boolean | undefined;
            defaultCatalogImagePath?: string | undefined;
            defaultCatalogCountryID?: string | undefined;
            defaultCatalogID?: string | undefined;
        } | undefined;
        maps?: {
            options?: {
                id?: string | undefined;
                accessToken?: string | undefined;
                attribution?: string | undefined;
            } | undefined;
            mapVisible?: boolean | undefined;
            useAnimation?: boolean | undefined;
            location?: [number[], number] | undefined;
            spatialType?: "Point" | "Polygon" | undefined;
            height?: string | undefined;
            width?: string | undefined;
            mapContainerId?: string | undefined;
            urlTemplate?: string | undefined;
            geoBoundsId?: string | undefined;
            sender?: {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
            } | undefined;
            receiver?: {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
                attributionPosition?: "topleft" | "topright" | "bottomleft" | "bottomright" | undefined;
            } | undefined;
            mapStyle?: {
                color?: string | undefined;
                fillColor?: string | undefined;
                fillOpacity?: number | undefined;
                weight?: number | undefined;
                radius?: number | undefined;
            } | undefined;
        } | undefined;
        dataProviderInterface?: {
            useService?: boolean | undefined;
            uploadFileTypes?: string[] | undefined;
            enableFileUploadReplace?: boolean | undefined;
            basePath?: string | undefined;
            specification?: "dcatap" | "dcatapde" | undefined;
            annifIntegration?: boolean | undefined;
            annifLinkTheme?: string | undefined;
            annifLinkSubject?: string | undefined;
            buttons?: {
                Dataset?: boolean | undefined;
                Catalogue?: boolean | undefined;
            } | undefined;
            doiRegistrationService?: {
                persistentIdentifierType?: string | undefined;
            } | undefined;
        } | undefined;
    }>>;
    /**
     * Language options (optional).
     */
    languages: z.ZodDefault<z.ZodObject<{
        useLanguageSelector: z.ZodDefault<z.ZodBoolean>;
        locale: z.ZodDefault<z.ZodString>;
        fallbackLocale: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        useLanguageSelector: boolean;
        locale: string;
        fallbackLocale: string;
    }, {
        useLanguageSelector?: boolean | undefined;
        locale?: string | undefined;
        fallbackLocale?: string | undefined;
    }>>;
    /**
     * Theming options (optional).
     */
    themes: z.ZodDefault<z.ZodObject<{
        header: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        header: string;
    }, {
        header?: string | undefined;
    }>>;
    /**
     * Tracker options (optional).
     */
    tracker: z.ZodDefault<z.ZodObject<{
        isPiwikPro: z.ZodDefault<z.ZodBoolean>;
        siteId: z.ZodDefault<z.ZodString>;
        trackerUrl: z.ZodDefault<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        isPiwikPro: boolean;
        siteId: string;
        trackerUrl: string;
    }, {
        isPiwikPro?: boolean | undefined;
        siteId?: string | undefined;
        trackerUrl?: string | undefined;
    }>>;
}, "strip", z.ZodTypeAny, {
    metadata: {
        title: string;
        description: string;
        keywords: string;
    };
    api: {
        baseUrl: string;
        hubUrl: string;
        qualityBaseUrl: string;
        similarityBaseUrl: string;
        similarityServiceName: string;
        fileUploadUrl: string;
        sparqlUrl: string;
        gazetteerBaseUrl: string;
        corsproxyApiUrl: string;
    };
    authentication: {
        login: {
            useLogin: boolean;
            loginTitle: string;
            loginURL: string;
            loginRedirectUri: string;
            logoutTitle: string;
            logoutURL: string;
            logoutRedirectUri: string;
        };
        useService: boolean;
        keycloak: {
            realm: string;
            clientId: string;
            'ssl-required': string;
            'public-client': boolean;
            'verify-token-audience': boolean;
            'use-resource-role-mappings': boolean;
            'confidential-port': number;
            url?: string | undefined;
        };
        keycloakInit: {
            onLoad: "check-sso" | "login-required";
            pkceMethod: string;
            useNone: boolean;
            adapter: string;
            checkLoginIframe: boolean;
            checkLoginIframeInterval: number;
            responseMode: "query" | "fragment" | "form_post";
            flow: "standard" | "implicit" | "hybrid";
            scope: string;
            token?: string | undefined;
            refreshToken?: string | undefined;
            idToken?: string | undefined;
            timeSkew?: number | undefined;
            redirectUri?: string | undefined;
            silentCheckSsoRedirectUri?: string | undefined;
        } & {
            [k: string]: unknown;
        };
        rtp: {
            grand_type: string;
            audience: string;
        };
        authToken: string;
        authMiddleware: {
            baseUrl: string;
            enable: boolean;
            loginRedirectUrl: string;
            logoutRedirectUrl: string;
        };
    } & {
        [k: string]: unknown;
    };
    routing: {
        routerOptions: {
            base: string;
            mode: string;
        };
        navigation: {
            showSparql: boolean;
        };
        pagination: {
            usePagination: boolean;
            usePaginationArrows: boolean;
            useItemsPerPage: boolean;
            defaultItemsPerPage: number;
            defaultItemsPerPageOptions: number[];
        };
    };
    content: {
        datasetDetails: {
            embed: {
                enable: boolean;
                defaultWidth: number;
                defaultHeight: number;
                minRange: number;
                maxRange: number;
            };
            header: {
                navigation: string;
                hidePublisher: boolean;
                hideDate: boolean;
            };
            description: {
                enableMarkdownInterpretation: boolean;
            };
            keywords: {
                showTitle: boolean;
                isVisible: boolean;
                collapsed: boolean;
            };
            dataServices: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            properties: string;
            distributions: {
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
                showValidationButton: boolean;
            };
            downloadAs: {
                url: string;
                enable: boolean;
                proxyUrl: string;
                conversionFormats: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[];
            };
            similarDatasets: {
                useSimilarDatasets: boolean;
                breakpoints: {
                    verySimilar: {
                        start: number;
                        end: number;
                    };
                    similar: {
                        start: number;
                        end: number;
                    };
                    lessSimilar: {
                        start: number;
                        end: number;
                    };
                };
            };
            pages: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            visualisations: {
                isVisible: boolean;
                displayAll: boolean;
                displayCount: number;
                incrementSteps: number[];
                descriptionMaxLines: number;
                descriptionMaxChars: number;
            };
            isUsedBy: {
                isVisible: boolean;
            };
            relatedResources: {
                isVisible: boolean;
            };
            bulkDownload: {
                buttonPosition: string;
                MAX_FILE_TITLE_LENGTH: number;
                MAX_REQUESTS_COUNT: number;
                INTERVAL_MS: number;
                TIMEOUT_MS: number;
            };
            quality: {
                displayAll: boolean;
                numberOfDisplayedQualityDistributions: number;
                csvLinter: {
                    enable: boolean;
                    displayAll: boolean;
                    numberOfDisplayedValidationResults: number;
                };
            };
        };
        datasets: {
            useSort: boolean;
            useFeed: boolean;
            useCatalogs: boolean;
            followKeywordLinks: string;
            maxKeywordLength: number;
            facets: {
                useDatasetFacets: boolean;
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                scoringFacets: {
                    useScoringFacets: boolean;
                    defaultScoringFacets: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }>;
                };
            };
        };
        catalogs: {
            useSort: boolean;
            facets: {
                useDatasetFacetsMap: boolean;
                showClearButton: boolean;
                showFacetsTitle: boolean;
                cutoff: number;
                MIN_FACET_LIMIT: number;
                MAX_FACET_LIMIT: number;
                FACET_OPERATORS: {
                    or: string;
                    and: string;
                };
                FACET_GROUP_OPERATORS: {
                    or: string;
                    and: string;
                };
                defaultFacetOrder: string[];
                useCatalogFacets: boolean;
            };
            useCatalogCountries: boolean;
            defaultCatalogImagePath: string;
            defaultCatalogCountryID: string;
            defaultCatalogID: string;
        };
        maps: {
            options: {
                id: string;
                accessToken: string;
                attribution: string;
            };
            mapVisible: boolean;
            useAnimation: boolean;
            location: [number[], number];
            spatialType: "Point" | "Polygon";
            height: string;
            width: string;
            mapContainerId: string;
            urlTemplate: string;
            geoBoundsId: string;
            sender: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
            };
            receiver: {
                height: string;
                width: string;
                mapContainerId: string;
                startBounds: [[number, number], [number, number]];
                attributionPosition: "topleft" | "topright" | "bottomleft" | "bottomright";
            };
            mapStyle: {
                color: string;
                fillColor: string;
                fillOpacity: number;
                weight: number;
                radius: number;
            };
        };
        dataProviderInterface: {
            useService: boolean;
            uploadFileTypes: string[];
            enableFileUploadReplace: boolean;
            basePath: string;
            specification: "dcatap" | "dcatapde";
            annifIntegration: boolean;
            annifLinkTheme: string;
            annifLinkSubject: string;
            buttons: {
                Dataset: boolean;
                Catalogue: boolean;
            };
            doiRegistrationService: {
                persistentIdentifierType: string;
            };
        };
    };
    languages: {
        useLanguageSelector: boolean;
        locale: string;
        fallbackLocale: string;
    };
    themes: {
        header: string;
    };
    tracker: {
        isPiwikPro: boolean;
        siteId: string;
        trackerUrl: string;
    };
}, {
    api: {
        baseUrl: string;
        hubUrl: string;
        qualityBaseUrl: string;
        similarityBaseUrl: string;
        fileUploadUrl: string;
        sparqlUrl: string;
        gazetteerBaseUrl: string;
        corsproxyApiUrl: string;
        similarityServiceName?: string | undefined;
    };
    metadata?: {
        title?: string | undefined;
        description?: string | undefined;
        keywords?: string | undefined;
    } | undefined;
    authentication?: z.objectInputType<{
        useService: z.ZodDefault<z.ZodBoolean>;
        login: z.ZodDefault<z.ZodObject<{
            useLogin: z.ZodDefault<z.ZodBoolean>;
            loginTitle: z.ZodDefault<z.ZodString>;
            loginURL: z.ZodDefault<z.ZodString>;
            loginRedirectUri: z.ZodDefault<z.ZodString>;
            logoutTitle: z.ZodDefault<z.ZodString>;
            logoutURL: z.ZodDefault<z.ZodString>;
            logoutRedirectUri: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            useLogin: boolean;
            loginTitle: string;
            loginURL: string;
            loginRedirectUri: string;
            logoutTitle: string;
            logoutURL: string;
            logoutRedirectUri: string;
        }, {
            useLogin?: boolean | undefined;
            loginTitle?: string | undefined;
            loginURL?: string | undefined;
            loginRedirectUri?: string | undefined;
            logoutTitle?: string | undefined;
            logoutURL?: string | undefined;
            logoutRedirectUri?: string | undefined;
        }>>;
        keycloak: z.ZodDefault<z.ZodObject<{
            realm: z.ZodDefault<z.ZodString>;
            url: z.ZodOptional<z.ZodString>;
            clientId: z.ZodDefault<z.ZodString>;
            'ssl-required': z.ZodDefault<z.ZodString>;
            'public-client': z.ZodDefault<z.ZodBoolean>;
            'verify-token-audience': z.ZodDefault<z.ZodBoolean>;
            'use-resource-role-mappings': z.ZodDefault<z.ZodBoolean>;
            'confidential-port': z.ZodDefault<z.ZodNumber>;
        }, "strip", z.ZodTypeAny, {
            realm: string;
            clientId: string;
            'ssl-required': string;
            'public-client': boolean;
            'verify-token-audience': boolean;
            'use-resource-role-mappings': boolean;
            'confidential-port': number;
            url?: string | undefined;
        }, {
            realm?: string | undefined;
            url?: string | undefined;
            clientId?: string | undefined;
            'ssl-required'?: string | undefined;
            'public-client'?: boolean | undefined;
            'verify-token-audience'?: boolean | undefined;
            'use-resource-role-mappings'?: boolean | undefined;
            'confidential-port'?: number | undefined;
        }>>;
        keycloakInit: z.ZodDefault<z.ZodObject<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, "passthrough", z.ZodTypeAny, z.objectOutputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">, z.objectInputType<{
            pkceMethod: z.ZodDefault<z.ZodString>;
            useNone: z.ZodDefault<z.ZodBoolean>;
            adapter: z.ZodDefault<z.ZodString>;
            onLoad: z.ZodDefault<z.ZodEnum<["check-sso", "login-required"]>>;
            token: z.ZodOptional<z.ZodString>;
            refreshToken: z.ZodOptional<z.ZodString>;
            idToken: z.ZodOptional<z.ZodString>;
            timeSkew: z.ZodOptional<z.ZodNumber>;
            checkLoginIframe: z.ZodDefault<z.ZodBoolean>;
            checkLoginIframeInterval: z.ZodDefault<z.ZodNumber>;
            responseMode: z.ZodDefault<z.ZodEnum<["query", "fragment", "form_post"]>>;
            flow: z.ZodDefault<z.ZodEnum<["standard", "implicit", "hybrid"]>>;
            scope: z.ZodDefault<z.ZodString>;
            redirectUri: z.ZodOptional<z.ZodString>;
            silentCheckSsoRedirectUri: z.ZodOptional<z.ZodString>;
        }, z.ZodTypeAny, "passthrough">>>;
        rtp: z.ZodDefault<z.ZodObject<{
            grand_type: z.ZodDefault<z.ZodString>;
            audience: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            grand_type: string;
            audience: string;
        }, {
            grand_type?: string | undefined;
            audience?: string | undefined;
        }>>;
        authToken: z.ZodDefault<z.ZodString>;
        authMiddleware: z.ZodDefault<z.ZodObject<{
            enable: z.ZodDefault<z.ZodBoolean>;
            baseUrl: z.ZodDefault<z.ZodString>;
            loginRedirectUrl: z.ZodDefault<z.ZodString>;
            logoutRedirectUrl: z.ZodDefault<z.ZodString>;
        }, "strip", z.ZodTypeAny, {
            baseUrl: string;
            enable: boolean;
            loginRedirectUrl: string;
            logoutRedirectUrl: string;
        }, {
            baseUrl?: string | undefined;
            enable?: boolean | undefined;
            loginRedirectUrl?: string | undefined;
            logoutRedirectUrl?: string | undefined;
        }>>;
    }, z.ZodTypeAny, "passthrough"> | undefined;
    routing?: {
        routerOptions?: {
            base?: string | undefined;
            mode?: string | undefined;
        } | undefined;
        navigation?: {
            showSparql?: boolean | undefined;
        } | undefined;
        pagination?: {
            usePagination?: boolean | undefined;
            usePaginationArrows?: boolean | undefined;
            useItemsPerPage?: boolean | undefined;
            defaultItemsPerPage?: number | undefined;
            defaultItemsPerPageOptions?: number[] | undefined;
        } | undefined;
    } | undefined;
    content?: {
        datasetDetails?: {
            embed?: {
                enable?: boolean | undefined;
                defaultWidth?: number | undefined;
                defaultHeight?: number | undefined;
                minRange?: number | undefined;
                maxRange?: number | undefined;
            } | undefined;
            header?: {
                navigation?: string | undefined;
                hidePublisher?: boolean | undefined;
                hideDate?: boolean | undefined;
            } | undefined;
            description?: {
                enableMarkdownInterpretation?: boolean | undefined;
            } | undefined;
            keywords?: {
                showTitle?: boolean | undefined;
                isVisible?: boolean | undefined;
                collapsed?: boolean | undefined;
            } | undefined;
            dataServices?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            properties?: string | undefined;
            distributions?: {
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
                showValidationButton?: boolean | undefined;
            } | undefined;
            downloadAs?: {
                url?: string | undefined;
                enable?: boolean | undefined;
                proxyUrl?: string | undefined;
                conversionFormats?: {
                    sourceFileFormat: string;
                    targetFileFormat: string[];
                }[] | undefined;
            } | undefined;
            similarDatasets?: {
                useSimilarDatasets?: boolean | undefined;
                breakpoints?: {
                    verySimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    similar?: {
                        start: number;
                        end: number;
                    } | undefined;
                    lessSimilar?: {
                        start: number;
                        end: number;
                    } | undefined;
                } | undefined;
            } | undefined;
            pages?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            visualisations?: {
                isVisible?: boolean | undefined;
                displayAll?: boolean | undefined;
                displayCount?: number | undefined;
                incrementSteps?: number[] | undefined;
                descriptionMaxLines?: number | undefined;
                descriptionMaxChars?: number | undefined;
            } | undefined;
            isUsedBy?: {
                isVisible?: boolean | undefined;
            } | undefined;
            relatedResources?: {
                isVisible?: boolean | undefined;
            } | undefined;
            bulkDownload?: {
                buttonPosition?: string | undefined;
                MAX_FILE_TITLE_LENGTH?: number | undefined;
                MAX_REQUESTS_COUNT?: number | undefined;
                INTERVAL_MS?: number | undefined;
                TIMEOUT_MS?: number | undefined;
            } | undefined;
            quality?: {
                displayAll?: boolean | undefined;
                numberOfDisplayedQualityDistributions?: number | undefined;
                csvLinter?: {
                    enable?: boolean | undefined;
                    displayAll?: boolean | undefined;
                    numberOfDisplayedValidationResults?: number | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        datasets?: {
            useSort?: boolean | undefined;
            useFeed?: boolean | undefined;
            useCatalogs?: boolean | undefined;
            followKeywordLinks?: string | undefined;
            maxKeywordLength?: number | undefined;
            facets?: {
                useDatasetFacets?: boolean | undefined;
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                scoringFacets?: {
                    useScoringFacets?: boolean | undefined;
                    defaultScoringFacets?: Record<string, {
                        title: string;
                        id: string;
                        count: number;
                        minScoring: number;
                        maxScoring: number;
                    }> | undefined;
                } | undefined;
            } | undefined;
        } | undefined;
        catalogs?: {
            useSort?: boolean | undefined;
            facets?: {
                useDatasetFacetsMap?: boolean | undefined;
                showClearButton?: boolean | undefined;
                showFacetsTitle?: boolean | undefined;
                cutoff?: number | undefined;
                MIN_FACET_LIMIT?: number | undefined;
                MAX_FACET_LIMIT?: number | undefined;
                FACET_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                FACET_GROUP_OPERATORS?: {
                    or?: string | undefined;
                    and?: string | undefined;
                } | undefined;
                defaultFacetOrder?: string[] | undefined;
                useCatalogFacets?: boolean | undefined;
            } | undefined;
            useCatalogCountries?: boolean | undefined;
            defaultCatalogImagePath?: string | undefined;
            defaultCatalogCountryID?: string | undefined;
            defaultCatalogID?: string | undefined;
        } | undefined;
        maps?: {
            options?: {
                id?: string | undefined;
                accessToken?: string | undefined;
                attribution?: string | undefined;
            } | undefined;
            mapVisible?: boolean | undefined;
            useAnimation?: boolean | undefined;
            location?: [number[], number] | undefined;
            spatialType?: "Point" | "Polygon" | undefined;
            height?: string | undefined;
            width?: string | undefined;
            mapContainerId?: string | undefined;
            urlTemplate?: string | undefined;
            geoBoundsId?: string | undefined;
            sender?: {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
            } | undefined;
            receiver?: {
                height?: string | undefined;
                width?: string | undefined;
                mapContainerId?: string | undefined;
                startBounds?: [[number, number], [number, number]] | undefined;
                attributionPosition?: "topleft" | "topright" | "bottomleft" | "bottomright" | undefined;
            } | undefined;
            mapStyle?: {
                color?: string | undefined;
                fillColor?: string | undefined;
                fillOpacity?: number | undefined;
                weight?: number | undefined;
                radius?: number | undefined;
            } | undefined;
        } | undefined;
        dataProviderInterface?: {
            useService?: boolean | undefined;
            uploadFileTypes?: string[] | undefined;
            enableFileUploadReplace?: boolean | undefined;
            basePath?: string | undefined;
            specification?: "dcatap" | "dcatapde" | undefined;
            annifIntegration?: boolean | undefined;
            annifLinkTheme?: string | undefined;
            annifLinkSubject?: string | undefined;
            buttons?: {
                Dataset?: boolean | undefined;
                Catalogue?: boolean | undefined;
            } | undefined;
            doiRegistrationService?: {
                persistentIdentifierType?: string | undefined;
            } | undefined;
        } | undefined;
    } | undefined;
    languages?: {
        useLanguageSelector?: boolean | undefined;
        locale?: string | undefined;
        fallbackLocale?: string | undefined;
    } | undefined;
    themes?: {
        header?: string | undefined;
    } | undefined;
    tracker?: {
        isPiwikPro?: boolean | undefined;
        siteId?: string | undefined;
        trackerUrl?: string | undefined;
    } | undefined;
}>;
export type ResolvedConfig = z.infer<typeof configSchema>;
export type Config = DeepPartial<ResolvedConfig> & {
    api: ResolvedConfig['api'];
    services: ResolvedConfig['services'];
};
